@@ -30,7 +30,7 @@ use Carp;
 use File::Temp;
 use Shell::GetEnv::Dumper;
 
-our $VERSION = '0.08_06';
+our $VERSION = '0.09_01';
 
 my $status_var = 'p5_SHELL_GETENV_STATUS';
 
@@ -85,7 +85,7 @@ my %shells = (
         echo        => 'x',
         verbose     => 'v',
         login       => 'l',
-        save_status => qq[setenv $status_var \$?],
+        save_status => qq[setenv $status_var \$status],
     },
 
     tcsh => {
@@ -94,7 +94,7 @@ my %shells = (
         echo        => 'x',
         verbose     => 'v',
         login       => 'l',
-        save_status => qq[setenv $status_var \$?],
+        save_status => qq[setenv $status_var \$status],
     },
 );
 
